@@ -25,11 +25,11 @@ Test2::Aggregate - Aggregate tests for increased speed
 
 =head1 VERSION
 
-Version 0.11_1
+Version 0.11_2
 
 =cut
 
-our $VERSION = '0.11_1';
+our $VERSION = '0.11_2';
 
 =head1 DESCRIPTION
 
@@ -58,7 +58,8 @@ more modern C<Test2::Suite> (see notes).
     my $stats = Test2::Aggregate::run_tests(
         dirs          => \@dirs,              # optional if lists defined
         lists         => \@lists,             # optional if dirs defined
-        excludes      => \@exclude_regexes,   # optional
+        exclude       => qr/exclude_regex/,   # optional
+        include       => qr/include_regex/,   # optional
         root          => '/testroot/',        # optional
         load_modules  => \@modules,           # optional
         package       => 0,                   # optional
@@ -106,9 +107,14 @@ paths inside the list files). If the path does not exist, it will be silently
 ignored, however the "official" way to skip a line without checking it as a path
 is to start with a C<#> (comment).
 
-=item * C<excludes> (optional)
+=item * C<exclude> (optional)
 
-Arrayref of strings with regex patterns to filter out tests that you want excluded.
+A regex to filter out tests that you want excluded.
+
+=item * C<include> (optional)
+
+A regex which the tests have to match in order to be included in the test run.
+Applied after C<exclude>.
 
 =item * C<root> (optional)
 
@@ -173,9 +179,9 @@ they are generated leave this option disabled.
 Instead of running the tests, will do C<ok($testname)> for each one. Otherwise,
 test order, stats files etc. will be produced normally.
 
-=item * C<stats_output_path> (optional)
+=item * C<stats_output> (optional)
 
-C<stats_output_path> specifies a path where a file will be created to print out
+C<stats_output> specifies a path where a file will be created to print out
 running time per test (average if multiple iterations) and passing percentage.
 Output is sorted from slowest test to fastest. On negative C<repeat> the stats
 of each successful run will be written separately instead of the averages.
@@ -183,11 +189,14 @@ The name of the file is C<caller_script-YYYYMMDDTHHmmss.txt>.
 If C<'-'> is passed instead of a path, then the output will be written to STDOUT.
 The timing stats are useful because the test harness doesn't normally measure
 time per subtest (remember, your individual aggregated tests become subtests).
+If you prefer to capture the hash output of the function and use that for your
+reports, you still need to define C<stats_output> to enable timing (just send
+the output to C</dev/null>, C</tmp> etc).
 
 =item * C<extend_stats> (optional)
 
-This option is to make the default output of C<stats_output_path> be fixed, but
-still allow additions in future versions that will only be written with the
+This option exist to make the default output format of C<stats_output> be fixed,
+but still allow additions in future versions that will only be written with the
 C<extend_stats> option enabled.
 Additions with C<extend_stats> as of current version:
 
@@ -282,9 +291,8 @@ sub _process_run_order {
     my $tests = shift;
     my $args  = shift;
 
-    foreach my $regex (@{$args->{excludes}}) {
-        @$tests = grep(!/$regex/, @$tests);
-    }
+    @$tests = grep(!/$args->{exclude}/, @$tests) if $args->{exclude};
+    @$tests = grep(/$args->{include}/, @$tests) if $args->{include};
 
     @$tests = _uniq(@$tests)  if $args->{unique};
     @$tests = reverse @$tests if $args->{reverse};
@@ -441,9 +449,9 @@ for a number of reasons, compatibility with this module being only a very minor
 one. If you are stuck with a C<Test::More> suite, C<Test2::Aggregate> can still
 probably help you more than the similarly-named C<Test::Aggregate...> modules.
 
-Although the module tries to load C<Test2> in a way to not interfere, it is generally
-better to do C<use Test::More;> in your aggregating test (i.e. alongside with
-C<use Test2::Aggregate>.
+Although the module tries to load C<Test2> with minimal imports to not interfere,
+it is generally better to do C<use Test::More;> in your aggregating test (i.e.
+alongside with C<use Test2::Aggregate>.
 
 One more caveat is that C<Test2::Aggregate::run_tests> uses C<subtest> from the
 C<Test2::Suite>, which on rare occasions can return a true value when a C<Test::More>
@@ -460,6 +468,9 @@ the individual test files:
 
  eval 'use My::Module' unless $ENV{AGGREGATE_TESTS};
 
+You can also make a test abort/die if you know it should not be aggregated by
+checking the variable.
+
 =head1 AUTHOR
 
 Dimitrios Kechagias, C<< <dkechag at cpan.org> >>
